package com.example.mygym.components

import android.util.Log
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import coil.compose.AsyncImagePainter
import coil.compose.rememberAsyncImagePainter
import coil.request.ImageRequest
import coil.size.Size
import com.example.mygym.domain.Constants
import com.example.mygym.model.Memberships
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext

@Preview
@Composable
fun MembershipList() {
    var memberships = remember { mutableStateOf<List<Memberships>>(listOf()) }

    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            try {
                // Запрос к базе данных
                val result = Constants.supabase.from("Memberships")
                    .select().decodeList<Memberships>()

                // Обновление состояния
                memberships.value = result

                // Логгирование
                memberships.value.forEach { it ->
                    Log.d("C", it.membership_name)
                }
            } catch (e: Exception) {
                Log.e("Error", "Failed to fetch memberships: ${e.message}")
            }
        }
    }

    LazyColumn {
        items(
            memberships.value,
            key = { membership -> membership.id }
        ) { membership ->
            val imageState = rememberAsyncImagePainter(
                model = ImageRequest.Builder(LocalContext.current).data(membership.image)
                    .size(Size.ORIGINAL).build(),
                onError = {
                    Log.e("ImageError", "Failed to load image for ${membership.membership_name}")
                }
            )

            if (imageState.state is AsyncImagePainter.State.Error) {
                Box(
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(200.dp),
                    contentAlignment = Alignment.Center
                ) {
                    CircularProgressIndicator()
                }
            }

            if (imageState.state is AsyncImagePainter.State.Success) {
                Image(
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(200.dp),
                    painter = imageState,
                    contentDescription = "",
                    contentScale = ContentScale.Crop
                )
            }

            Text(
                membership.membership_name,
                modifier = Modifier.padding(8.dp),
            )
        }


    }
}
